==> simbricks_cli-0.0.2.tar.gz: simbricks_cli-0.0.2/simbricks/cli/__main__.py <==
# Copyright 2024 Max Planck Institute for Software Systems, and
# National University of Singapore
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from typer import Typer, Option
from typing_extensions import Annotated
from simbricks.cli.commands import audit, admin, namespaces, runs, systems, simulations, instantiations
from simbricks.cli.state import state
from simbricks.cli.utils import async_cli

app = Typer()
app.add_typer(namespaces.app, name="ns")
app.add_typer(runs.app, name="runs")
app.add_typer(audit.app, name="audit")
app.add_typer(admin.app, name="admin")
app.add_typer(systems.app, name="systems")
app.add_typer(simulations.app, name="sims")
app.add_typer(instantiations.app, name="insts")


@app.callback()
@async_cli()
async def amain(
    ns: Annotated[str, Option(help="Namespace to operate in.")] = "foo/bar/baz",
):
    state.namespace = ns


def main():
    app()


if __name__ == "__main__":
    main()

==> simbricks_cli-0.3.3.tar.gz: simbricks_cli-0.3.3/simbricks/cli/__main__.py <==
# Copyright 2024 Max Planck Institute for Software Systems, and
# National University of Singapore
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from typer import Typer, Option
from typing_extensions import Annotated
from simbricks.cli.commands import (
    audit,
    admin,
    org,
    namespaces,
    rg,
    runs,
    systems,
    simulations,
    instantiations,
    runners,
)
from simbricks.client.provider import client_provider
from simbricks.client.settings import client_settings
from simbricks.cli.utils import async_cli

app = Typer(pretty_exceptions_show_locals=False)
app.add_typer(namespaces.app, name="ns")
app.add_typer(runs.app, name="runs")
app.add_typer(audit.app, name="audit")
app.add_typer(admin.app, name="admin")
app.add_typer(org.app, name="org")
app.add_typer(systems.app, name="systems")
app.add_typer(simulations.app, name="sims")
app.add_typer(instantiations.app, name="insts")
app.add_typer(runners.app, name="runners")
app.add_typer(rg.app, name="rg")


@app.callback()
@async_cli()
async def amain(
    ns: Annotated[str, Option(help="Namespace to operate in.")] = client_settings().namespace,
):
    client_provider.namespace = ns


def main():
    app()


if __name__ == "__main__":
    main()
